@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2017, 2018 Scott Shawcroft for Adafruit Industries
 #
-# Copyright (c) 2017, 2018 Scott Shawcroft for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_rtttl`
 ====================================================
@@ -33,7 +16,7 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_RTTTL"
 
 import sys
 import time
-import pulseio
+import pwmio
 
 AUDIOIO_AVAILABLE = False
 try:
@@ -128,9 +111,8 @@ def _get_wave(tune, octave):
 
 # pylint: disable-msg=too-many-arguments
 def _play_to_pin(tune, base_tone, min_freq, duration, octave, tempo):
-    """Using the prepared input send the notes to the pin
-    """
-    pwm = isinstance(base_tone, pulseio.PWMOut)
+    """Using the prepared input send the notes to the pin"""
+    pwm = isinstance(base_tone, pwmio.PWMOut)
     for note in tune.split(","):
         piano_note, note_duration = _parse_note(note, duration, octave)
         if piano_note in PIANO:
@@ -197,7 +179,7 @@ def play(pin, rtttl, octave=None, duration=None, tempo=None):
 
     # Fall back to PWM
     if not base_tone:
-        base_tone = pulseio.PWMOut(pin, duty_cycle=0, variable_frequency=True)
+        base_tone = pwmio.PWMOut(pin, duty_cycle=0, variable_frequency=True)
 
     _play_to_pin(tune, base_tone, min_freq, duration, octave, tempo)
 
